UiDsl

Struct UiDsl 

pub struct UiDsl<D = LayoutDsl> { /* private fields */ }
The DslBundle for bevy_ui.

Implementations

Source

impl<D> UiDsl<D>

pub fn border_px(&mut self, pixels: u16)

Set the node’s border width, in pixels. Note that this is only visual and has no effect on the cuicui_layout algorithm.

Due to a limitation of CSS, border will be spawned as a child of the actual node entity.

This is because it would be otherwise impossible to arrange children independently of parent properties.

pub fn border(&mut self, pixels: u16, color: Color)

Set the node’s border color and width.

pub fn border_color(&mut self, color: Color)

Set the node’s border color.

Due to a limitation of CSS, border will be spawned as a child of the actual node entity.

This is because it would be otherwise impossible to arrange children independently of parent properties.

pub fn bg(&mut self, color: Color)

Set the node’s background color.

pub fn image(&mut self, image: &Handle<Image>)

Set the node’s background image.

pub fn flip_x(&mut self)

If this node has a background image, flip it on its X axis.

pub fn flip_y(&mut self)

If this node has a background image, flip it on its Y axis.

pub fn text(&mut self, text: &str)

Set the node’s text.

pub fn break_on_char(&mut self)

If this node contains text, set its break behavior to breaking on individual characters.

By default, text breaks on word.

pub fn no_wrap(&mut self)

If this node contains text, only go to next line on ‘\n’ in text.

By default, text breaks on word.

pub fn text_right_align(&mut self)

If this node contains text, align it to the left.

By default, text is aligned left

pub fn text_center_align(&mut self)

If this node contains text, align it to the center.

By default, text is aligned left.

pub fn font_size(&mut self, size: u16)

Set the text size for this node.

pub fn font(&mut self, font: &Handle<Font>)

Set the text font.