pub struct UiDsl<D = LayoutDsl> { /* private fields */ }Expand description
The DslBundle for bevy_ui.
Implementations
Sourceimpl<D> UiDsl<D>
impl<D> UiDsl<D>
Sourcepub fn border_px(&mut self, pixels: u16)
pub fn border_px(&mut self, pixels: u16)
Set the node’s border width, in pixels. Note that this is only visual and has
no effect on the cuicui_layout algorithm.
Due to a limitation of CSS, border will be spawned as a child of the actual node entity.
This is because it would be otherwise impossible to arrange children independently of parent properties.
Sourcepub fn border_color(&mut self, color: Color)
pub fn border_color(&mut self, color: Color)
Set the node’s border color.
Due to a limitation of CSS, border will be spawned as a child of the actual node entity.
This is because it would be otherwise impossible to arrange children independently of parent properties.
Sourcepub fn break_on_char(&mut self)
pub fn break_on_char(&mut self)
If this node contains text, set its break behavior to breaking on individual characters.
By default, text breaks on word.
Sourcepub fn no_wrap(&mut self)
pub fn no_wrap(&mut self)
If this node contains text, only go to next line on ‘\n’ in text.
By default, text breaks on word.
Sourcepub fn text_right_align(&mut self)
pub fn text_right_align(&mut self)
If this node contains text, align it to the left.
By default, text is aligned left
Sourcepub fn text_center_align(&mut self)
pub fn text_center_align(&mut self)
If this node contains text, align it to the center.
By default, text is aligned left.